package cn.sh.stc.sict.theme.hpgp.controller.mobile;


import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.sh.stc.sict.cloud.common.core.constant.Constant;
import cn.sh.stc.sict.cloud.common.core.util.NumberUtil;
import cn.sh.stc.sict.cloud.common.core.util.R;
import cn.sh.stc.sict.cloud.common.security.util.SecurityUtils;
import cn.sh.stc.sict.cloud.upms.dto.CurrentUser;
import cn.sh.stc.sict.theme.hpgp.model.HpAppointmentEva;
import cn.sh.stc.sict.theme.hpgp.service.HpAppointmentEvaService;
import cn.sh.stc.sict.theme.hphy.model.HpAppointment;
import cn.sh.stc.sict.theme.hphy.service.HpAppointmentService;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import java.util.Date;

@Slf4j
@RestController
@AllArgsConstructor
@Api(tags = "[C]预约评价")
@RequestMapping("/hp/app/eva")
public class HpAppointmentEvaController {
    /**
     * 1. 已评价 page
     * 2. 待评价 page
     * 3. 评价
     */
    private final HpAppointmentService hpAppointmentService;
    private final HpAppointmentEvaService hpAppointmentEvaService;

    @ApiOperation("已评价 分页")
    @GetMapping("/eaved/page")
    public R hasEavedPage(Page page, @RequestParam("patientId") Long patientId) {
        LambdaQueryWrapper<HpAppointmentEva> wrapper = Wrappers.lambdaQuery();
        wrapper.eq(HpAppointmentEva::getPatientId, patientId);
        return new R(hpAppointmentEvaService.page(page, wrapper));
    }

    @ApiOperation("待评价 分页")
    @GetMapping("/todo/eav/page")
    public R toBeEavPage(Page page, @RequestParam("patientId") Long patientId) {
        page = hpAppointmentEvaService.toBeEavPage(page, patientId);
        return new R(page);
    }

    @ApiOperation("评价")
    @PostMapping("/eva")
    @Transactional(rollbackFor = Exception.class)
    public R eav(@RequestBody HpAppointmentEva eva) {
        if(NumberUtil.isNullOrZero(eva.getAppId())){
            return new R().error("appId 不可为空！");
        }
        if(NumberUtil.isNullOrZero(eva.getPatientId())){
            return new R().error("patientId 不可为空！");
        }
        HpAppointment app = hpAppointmentService.getById(eva.getId());
        if(ObjectUtil.isNull(app)){
            return new R().error("未找到预约记录！");
        }
        if(!Constant.BYTE_NO.equals(app.getEvaStatus())){
            return new R().error("该预约记录已评价！");
        }
        CurrentUser current = SecurityUtils.getCurrentUser();
        eva.setUserId(current.getId());
        eva.setHospCode(app.getHosOrgCode());
        eva.setHospName(app.getHosOrgName());
        eva.setDeptCode(app.getDeptCode());
        eva.setDeptName(app.getDeptName());
        eva.setDoctorCode(app.getDoctorId());
        eva.setDoctorName(app.getDoctorName());
        eva.setCreateTime(DateUtil.date());
        hpAppointmentEvaService.save(eva);
        HpAppointment update = new HpAppointment();
        update.setId(eva.getAppId());
        update.setEvaStatus(Constant.BYTE_YES);
        hpAppointmentService.updateById(update);
        return new R();
    }
}